\name{FORM-AT}
\alias{FORM-Ang&Tang}
\title{
	Solution of the first-order reliability method (FORM) using Ang and Tang (1984) 's algorithm 
}
\description{
	Application to a bearing capacity problem associated with two variables
}
\arguments{
  \item{mu1}{
	mean of unit weight
}
  \item{sd1}{
	standard deviation of unit weight
}
  \item{mu2}{
	mean of internal angle of friction
}
  \item{sd2}{
	standard deviation of internal angle of friction
}
  \item{rou}{
	correlation coefficient between unit weight and internal angle of friction
}
}
\details{
	The case study discusses the solution with a correlated bivariate distribution.
}
\value{
	Returns a reliability index.
}
\references{
	Wu XZ. 2017. Implementing multivariate fitting and reliability analyses for geotechnical engineering problems in R. Georisk, 11(2):173-188.
}
\note{
	
	Please read the following references for the original data (adopted from):

	[1] Ang A H S and Tang W H 1984 Probability Concepts in Engineering Planning and Design. Volume II, Decision, risk and reliability; John Wiley, New York, 562pp.

	[2] Phoon K K and Honjo Y 2005 Geotechnical reliability analyses: towards development of some user-friendly tools; In Proceedings of the 16th International Conference on Soil Mechanics and Geotechnical engineering. Osaka. 
  
}
\seealso{

	Wu X.Z. 2013. Probabilistic slope stability analysis by a copula-based sampling method. Computational Geosciences. 2013. 17(5):739-755.
}
\author{
Xingzheng
Wu \email{xingzhengwu@gmail.com}

}
\examples{
	##---- Should be DIRECTLY executable !! ----
	##--	listing the code.
	library(rootSolve) #for uniroot.all( )
	library(mosaic) #for D( )
	Y_mu=18; Y_sd=Y_mu*0.1; Z_mu=40; Z_sd=Z_mu*0.2; X12.Corr<-0.66
	DD<-10; BW<-1; ed<-1; FL<-1000
	dTerm<-0.5/(ed+DD)*BW*DD^3
	corrm2<-matrix(c(1,X12.Corr,X12.Corr,1.0),ncol=2,nrow=2,byrow=TRUE)
	eig<-eigen(corrm2,EISPACK=FALSE); eig.X01<-eig$values[1]; 
	eig.X02<-eig$values[2]; tranMat<-eig$vectors;
	for (iTer in 1:100) { # iteration start
		if (iTer==1) {Y1<-0; Y2<-0; X0.sigma.mat<-diag(c(Y_sd,Z_sd)); 
		muX<-as.matrix(c(Y_mu,Z_mu));
		CY<-X0.sigma.mat * tranMat; 

		#----------------------------------------------------------------------
		# please replace * by %*% for matrix Multiplication in above line or see demo code !!!!
		#----------------------------------------------------------------------

		Beta<-0.0; BetaNew1<-3
		}
		
		dBeta<-abs(Beta-BetaNew1)
		if (dBeta<=0.0002) {Beta; break} #success and exit
		
		if (iTer!=1) {Y1<-X21.Mn; Y2<-X22.Mn}
		Beta<-BetaNew1
		D.Y1Fun<-D(dTerm*(CY11*Y1+CY12*Y2+muX1)*(tan((45+0.5*(CY21*Y1+CY22*Y2+muX2))/180*pi))^2-FL~Y1)
		D.Y2Fun<-D(dTerm*(CY11*Y1+CY12*Y2+muX1)*(tan((45+0.5*(CY21*Y1+CY22*Y2+muX2))/180*pi))^2-FL~Y2)
		D.Y1Val<-D.Y1Fun(CY11=CY[1,1],CY21=CY[2,1],CY12=CY[1,2],Y1=Y1,CY22=CY[2,2],
		Y2=Y2,muX2=muX[2],muX1=muX[1],dTerm=dTerm,FL=FL)
		D.Y2Val<-D.Y2Fun(CY11=CY[1,1],CY21=CY[2,1],CY12=CY[1,2],Y1=Y1,CY22=CY[2,2],
		Y2=Y2,muX2=muX[2],muX1=muX[1],dTerm=dTerm,FL=FL)
		D.Y1Vals<-D.Y1Val*sqrt(eig.X01); D.Y2Vals<-D.Y2Val*sqrt(eig.X02)
		
		Alfa.Y1<-D.Y1Vals/sqrt(D.Y1Vals*D.Y1Vals+D.Y2Vals*D.Y2Vals)
		Alfa.Y2<-D.Y2Vals/sqrt(D.Y1Vals*D.Y1Vals+D.Y2Vals*D.Y2Vals)
		DP.Y1<--Alfa.Y1*sqrt(eig.X01); DP.Y2<--Alfa.Y2*sqrt(eig.X02)
		
		CY11=CY[1,1]; CY21=CY[2,1]; CY12=CY[1,2]; CY22=CY[2,2]; muX1=muX[1]; muX2=muX[2];
		
		g109.x<-function(x)(dTerm*(CY11*x*DP.Y1+CY12*x*DP.Y2+muX1)*(tan((45+0.5*
		(CY21*x*DP.Y1+CY22*x*DP.Y2+muX2))/180*pi))^2-FL)
		BetaNew<-uniroot.all(g109.x, interval=c(0,250)); BetaNew1<-min(BetaNew)
		
		X21.Mn<-DP.Y1*BetaNew1; X22.Mn<-DP.Y2*BetaNew1;
	} #next iTer
	BetaNew1
}