\name{FORM-XiFun}
\alias{FORM-XiFun}
\title{
	Define the original basic variables by the dimensionless numbers using Low and Tang (2007) 's algorithm 
}
\description{
	Application xi funtion to derive x from xi for any distribution types
}
\arguments{
  \item{mu}{
	mean
}
  \item{sd}{
	standard deviation
}
  \item{para1}{
	parameter of a distribution
}
  \item{para2}{
	parameter of a distribution
}
  \item{DistName}{
	name of a distribution
}
}
\details{
	The distribution can be specified by the normal, lognormal, Gumbel, Weibull, gamma, and beta. 
}
\value{
	Returns xi.
}
\note{
	The following R code is modified from the VB ones written by Low and Tang (2007).
}
\references{
	[1] Low B K and Tang W H 2007 Efficient spreadsheet algorithm for first-order reliability method; J. Eng. Mech. 133(12) 1378-1387.
	[2] Low B K and Tang W H 1997 Efficient reliability evaluation using spreadsheets; J. Eng. Mech. 123(7) 749-752.
}
\seealso{

	Wu X.Z. 2013. Probabilistic slope stability analysis by a copula-based sampling method. Computational Geosciences. 2013. 17(5):739-755.
}
\author{
Xingzheng
Wu \email{xingzhengwu@gmail.com}

}
\examples{
	##---- Should be calling by FORM-LT !! ----
	##--	listing the code.
		 ln <- function(x) { log(x, 2.718281828)}

		FunXiLT<-function(DistName, para1,para2, ni){
			if (DistName=="norm") {
			  xi_LT=para1+ni*para2
			}
			if (DistName=="lnorm") {
			  lamda=log(para1)-0.5*log(1+(para2/para1)^2)
			  zeta = sqrt(log(1+(para2/para1)^2))
			  xi_LT = exp(lamda+zeta*ni)
			}
			if (DistName=="gumbel") {
			  alfa=1.28255/para2
			  u=para1-0.5772/alfa
			  xi_LT =u-log(-log(pnorm(ni)))/alfa
			}
			if (DistName=="weibull") {
			  xi_LT =para2*(-log(1-pnorm(ni)))^(1/para1)
			}
			if (DistName=="gamma") {
			  xprev=para1*para2
			  for (i in 1:100) {
			    pdfg=dgamma(xprev,para1,1/para2)
			    xnew=xprev-(CDFg-pnorm(ni))/pdfg
			    if (abs((xnew-xprev)/xprev)<0.000001) break
			    if (xnew<=0) xnew=0.5*xprev
			    xprev=xnew
			  }
			  xi_LT=xnew
			}
			
			list(xi_LT=xi_LT)
		}

	}