\name{PSIRegPars}
\alias{PSIRegPars}
\title{
	Regression parameters for bearing capacity versus settlement curve of pile-soil intermediate (PSI)
}
\description{
	Data sets covers the regression parameters via hyperbolic and power law
}
\usage{
	PSIRegPars(h1, h2)
	PSIRegPars(p1, p2)
}
\arguments{
  \item{h1}{
	a hyperbolic regression parameter
}
  \item{h2}{
	a hyperbolic regression parameter
}
  \item{p1}{
	a power law regression parameter
}
  \item{p2}{
	a power law regression parameter
}
}
\details{
	The data set contains several columns : no, area, Pmax, Smax, Kur, p1, p2, 10000*h1, 100*h2.
}
\value{
	Returns a matrix that contains above values for each sites included in the data set.
}
\references{
	Wu XZ. 2017. Implementing multivariate fitting and reliability analyses for geotechnical engineering problems in R. Georisk, 11(2):173-188.
}
\note{

	Please read the following references for the original data (adopted from):

	[1] Wu XZ, Xin JX. 2019. Probabilistic analysis of site-specific load-displacement behaviour of cement-fly ash-gravel piles. Soils and Foundations, 59(5):1613-1630.
  
}
\seealso{

	Wu XZ, Xin JX. 2021. Geometric reliability analysis ofcomposite foundations comprising cement-fly ash-gravel piles atsite-specific scale. Journal of Testing and Evaluation, 49(4):2779-2799.
}
\author{
Xingzheng
Wu \email{xingzhengwu@gmail.com}

}
\examples{
	##---- Should be DIRECTLY executable !! ----
	##--	listing data.
	data(PSIRegPars)
	PSIRegPars[["name"]]  ##column named "name"

	which(PSIRegPars[["name"]]=="TZPSI")  ##returns a vector of the indices of x 
	which(PSIRegPars[["type"]]=="CI")  ##returns a vector of the indices of x at a site 
	PSIRegPars[which(PSIRegPars[["type"]]=="CI"),]   ##listing a matrix where the site = 'CI'
	PSIRegPars[which(PSIRegPars[["type"]]=="CI"),6:7]   
		##listing a matrix where the p1-p2 parameters at site = 'CI'
	PSIRegPars[which(PSIRegPars[["type"]]=="CI"),8:9]   
		##listing a matrix where the h1-h2 parameters at site = 'CI'
}
\keyword{Pmax}
\keyword{Smax}
\keyword{Kur}
