\name{SORM}
\alias{SORM-Phoon}
\title{
	Solution of the second-order reliability method (SORM) using Phoon (2008) 's algorithm 
}
\description{
	Application to a bearing capacity problem associated with two variables
}
\arguments{
  \item{mu1}{
	mean of unit weight
}
  \item{sd1}{
	standard deviation of unit weight
}
  \item{mu2}{
	mean of internal angle of friction
}
  \item{sd2}{
	standard deviation of internal angle of friction
}
  \item{rou}{
	correlation coefficient between unit weight and internal angle of friction
}
}
\details{
	The case study discusses the solution with a correlated bivariate distribution.
}
\value{
	Returns a reliability index.
}
\references{
	Wu XZ. 2017. Implementing multivariate fitting and reliability analyses for geotechnical engineering problems in R. Georisk, 11(2):173-188.
}
\note{
	
	This subroutine can be run after calling the first-order reliability analysis, i.e., FORM-LT.

	Please read the following references:

	[1] Breitung K 1984 Asymptotic approximations for multinormal integrals; J. Eng. Mech. (ASCE), 110(3) 357-366.

	[2] Phoon K K 2008 Numerical recipes for reliability analysis—a primer; In: Phoon, K.K. (Ed.), Reliability-based Design in Geotechnical Engineering: Computations and Applications. Taylor & Francis (Chapter 1).

	[3] Phoon K K and Honjo Y 2005 Geotechnical reliability analyses: towards development of some user-friendly tools; In Proceedings of the 16th International Conference on Soil Mechanics and Geotechnical engineering. Osaka. 
	
	[4] Tvedt L 1983 Two second-order approximations to the failure probability. Veritas Report RDIV/20-004083. Det norske Veritas. Veritas Report RDIV/20-004083: Oslo.
	
	[5] Tvedt L 1990 Distribution of quadratic forms in normal space: Application to structural reliability; J. Eng. Mech. (ASCE), 116(6) 1183-1197.

}
\seealso{

	Wu X.Z. 2013. Probabilistic slope stability analysis by a copula-based sampling method. Computational Geosciences. 2013. 17(5):739-755.
}
\author{
Xingzheng
Wu \email{xingzhengwu@gmail.com}

}
\examples{
	##---- Should be DIRECTLY executable !! ----
	##--	listing the code.
	pf1<-pnorm(-beta1)
	zz<-ret$par; mm<-nVars
	grad<-matrix(nrow=mm,ncol=1)
	for (i in 1:mm) {ww<-zz;
		ww[i]<-zz[i]+0.01; P2<-gFn(ww);
		ww[i]<-zz[i]-0.01; P1<-gFn(ww);
		grad[i]<-(P2-P1)/2/0.01}
	Hess<-matrix(nrow=mm,ncol=mm)
	for (i in 1:mm){
		for (j in 1:mm){ww<-zz;
			if (i==j) {P0<-gFn(ww); ww[i]<-zz[i]+0.01;
				P2<-gFn(ww); ww[i]<-zz[i]-0.01;
				P1<-gFn(ww); Hess[i,j]<-(P2-2*P0+P1)/(0.01)^2}
			if (i!=j) {ww[i]<-zz[i]+0.01; ww[j]<-zz[j]+0.01;
				P6<-gFn(ww); ww[j]<-zz[j]-0.01;
				P5<-gFn(ww); ww[i]<-zz[i]-0.01;
				P3<-gFn(ww); ww[j]<-zz[j]+0.01;
				P4<-gFn(ww); Hess[i,j]<-(P6-P4-P5+P3)/4/(0.01)^2}}}
	library(pracma) #Norm function
	dP<-Norm(grad); QQ<-diag(mm);
	QQ[1:mm,1]<-zz; qrstr<-qr(QQ)
	QQR<-qr.Q(qrstr); QQR1<-t(apply(QQR,1,rev))
	AA<-t(QQR1) * Hess * QQR1;
		
		#----------------------------------------------------------------------
		# please replace * by %*% for matrix Multiplication in above line or see demo code !!!!
		#----------------------------------------------------------------------

	AAN<-AA[1:mm-1,1:mm-1]/dP
	tmpEG=eigen(AAN); WW=tmpEG$values; kappa<-as.matrix(WW)
	correction1<-prod(1.0/sqrt(1+beta1*kappa),1);
	pf2<-pf1*correction1; #Breitung's formula
	beta2<--qnorm(pf2);
	TermAA<-beta1*pnorm(-beta1)-dnorm(-beta1)
	correction2<-prod(1.0/sqrt(1+(beta1+1)*kappa),1);
	A2Term<-TermAA*(correction1-correction2); i_complex<-sqrt(as.complex(-1))
	correction3<-Re(prod(1.0/sqrt(1+(beta1+i_complex)*kappa),1));
	A3Term<-(beta1+1)*TermAA*(correction1-correction3)
	pf3<-pf1*correction1+A2Term+A3Term; #Tvedt's formula
	beta3<--qnorm(pf3)

	beta2 #Breitung's solution
	beta3 #Tvedt's solution

}